@@ -1516,31 +1516,38 @@ když příště spustíte tento program.</translation>
         <translation>Ukázat podrobnosti</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="323"/>
+        <location filename="../qsynthPaletteForm.cpp" line="344"/>
         <source>Import File - %1</source>
         <translation>Zavést soubor - %1</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="326"/>
-        <location filename="../qsynthPaletteForm.cpp" line="400"/>
+        <location filename="../qsynthPaletteForm.cpp" line="260"/>
+        <location filename="../qsynthPaletteForm.cpp" line="347"/>
+        <location filename="../qsynthPaletteForm.cpp" line="392"/>
         <source>Palette files (*.%1)</source>
         <translation>Soubory s paletami (*.%1)</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="327"/>
-        <location filename="../qsynthPaletteForm.cpp" line="401"/>
+        <location filename="../qsynthPaletteForm.cpp" line="258"/>
+        <source>Save Palette - %1</source>
+        <translation>Uložit paletu - %1</translation>
+    </message>
+    <message>
+        <location filename="../qsynthPaletteForm.cpp" line="261"/>
+        <location filename="../qsynthPaletteForm.cpp" line="348"/>
+        <location filename="../qsynthPaletteForm.cpp" line="393"/>
         <source>All files (*.*)</source>
         <translation>Všechny soubory (*.*)</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="387"/>
-        <location filename="../qsynthPaletteForm.cpp" line="820"/>
-        <location filename="../qsynthPaletteForm.cpp" line="828"/>
+        <location filename="../qsynthPaletteForm.cpp" line="379"/>
+        <location filename="../qsynthPaletteForm.cpp" line="755"/>
+        <location filename="../qsynthPaletteForm.cpp" line="763"/>
         <source>Warning - %1</source>
         <translation>Varování - %1</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="388"/>
+        <location filename="../qsynthPaletteForm.cpp" line="380"/>
         <source>Could not import from file:
 
 %1
@@ -1553,12 +1560,12 @@ Sorry.</source>
 Promiňte.</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="397"/>
+        <location filename="../qsynthPaletteForm.cpp" line="389"/>
         <source>Export File - %1</source>
         <translation>Vyvést soubor - %1</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="821"/>
+        <location filename="../qsynthPaletteForm.cpp" line="756"/>
         <source>Some settings have been changed.
 
 Do you want to discard the changes?</source>
@@ -1567,7 +1574,7 @@ Do you want to discard the changes?</source>
 Chcete zahodit změny?</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="829"/>
+        <location filename="../qsynthPaletteForm.cpp" line="764"/>
         <source>Some settings have been changed:
 
 &quot;%1&quot;.
@@ -1583,22 +1590,22 @@ Chcete uložit změny?</translation>
 <context>
     <name>qsynthPaletteForm::PaletteModel</name>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="1072"/>
+        <location filename="../qsynthPaletteForm.cpp" line="1007"/>
         <source>Color Role</source>
         <translation>Barevná role</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="1075"/>
+        <location filename="../qsynthPaletteForm.cpp" line="1010"/>
         <source>Active</source>
         <translation>Činný</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="1078"/>
+        <location filename="../qsynthPaletteForm.cpp" line="1013"/>
         <source>Inactive</source>
         <translation>Nečinný</translation>
     </message>
     <message>
-        <location filename="../qsynthPaletteForm.cpp" line="1081"/>
+        <location filename="../qsynthPaletteForm.cpp" line="1016"/>
         <source>Disabled</source>
         <translation>Zakázáno</translation>
     </message>
@@ -1685,7 +1692,7 @@ Chcete uložit změny?</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="170"/>
-        <location filename="../qsynthSetupForm.ui" line="701"/>
+        <location filename="../qsynthSetupForm.ui" line="725"/>
         <source>MIDI device name</source>
         <translation>Název zařízení MIDI</translation>
     </message>
@@ -1695,38 +1702,38 @@ Chcete uložit změny?</translation>
         <translation>Ovladač pro vstup MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="305"/>
+        <location filename="../qsynthSetupForm.ui" line="311"/>
         <source>ALSA Sequencer client name identification</source>
         <translation>ID názvu klienta u ALSA sequenceru</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="312"/>
+        <location filename="../qsynthSetupForm.ui" line="318"/>
         <source>pid</source>
         <translation>pid</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="317"/>
-        <location filename="../qsynthSetupForm.ui" line="800"/>
+        <location filename="../qsynthSetupForm.ui" line="323"/>
+        <location filename="../qsynthSetupForm.ui" line="824"/>
         <source>qsynth</source>
         <translation>qsynth</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="360"/>
+        <location filename="../qsynthSetupForm.ui" line="366"/>
         <source>Whether to show MIDI router events on messages window</source>
         <translation>Ukázat události směrovače MIDI v okně hlášení</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="350"/>
+        <location filename="../qsynthSetupForm.ui" line="356"/>
         <source>Print out verbose messages about MIDI events</source>
         <translation>Zobrazit podrobná hlášení o událostech MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="353"/>
+        <location filename="../qsynthSetupForm.ui" line="359"/>
         <source>&amp;Verbose MIDI event messages</source>
         <translation>&amp;Podrobná hlášení o událostech MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="196"/>
+        <location filename="../qsynthSetupForm.ui" line="202"/>
         <source>Number of MIDI channels</source>
         <translation>Počet kanálů MIDI</translation>
     </message>
@@ -1746,47 +1753,47 @@ Chcete uložit změny?</translation>
         <translation>Spustit &amp;vstup MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="245"/>
+        <location filename="../qsynthSetupForm.ui" line="251"/>
         <source>gm</source>
         <translation>gm</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="250"/>
+        <location filename="../qsynthSetupForm.ui" line="256"/>
         <source>gs</source>
         <translation>gs</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="255"/>
+        <location filename="../qsynthSetupForm.ui" line="261"/>
         <source>mma</source>
         <translation>mma</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="260"/>
+        <location filename="../qsynthSetupForm.ui" line="266"/>
         <source>xs</source>
         <translation>xs</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="225"/>
+        <location filename="../qsynthSetupForm.ui" line="231"/>
         <source>MIDI &amp;Bank Select mode:</source>
         <translation>Režim výběru &amp;banky MIDI:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="238"/>
+        <location filename="../qsynthSetupForm.ui" line="244"/>
         <source>MIDI Bank Select mode</source>
         <translation>Režim výběru banky MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="371"/>
+        <location filename="../qsynthSetupForm.ui" line="377"/>
         <source>&amp;Audio</source>
         <translation>&amp;Zvuk</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="418"/>
+        <location filename="../qsynthSetupForm.ui" line="424"/>
         <source>Sample &amp;Format:</source>
         <translation>Vzorkovací &amp;formát (rozlišení):</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="408"/>
+        <location filename="../qsynthSetupForm.ui" line="414"/>
         <source>Output audio driver</source>
         <translation>Ovladač zvuku pro výstup</translation>
     </message>
@@ -1801,344 +1808,344 @@ Chcete uložit změny?</translation>
         <translation>&amp;Zařízení MIDI:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="292"/>
+        <location filename="../qsynthSetupForm.ui" line="298"/>
         <source>MIDI Client &amp;Name ID (ALSA/CoreMidi):</source>
         <translation>ID &amp;názvu klienta MIDI (ALSA/CoreMidi):</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="340"/>
+        <location filename="../qsynthSetupForm.ui" line="346"/>
         <source>Attempt to connect the MIDI inputs to the physical ports</source>
         <translation>Pokusit o spojení výstupů MIDI s fyzickými přípojkami</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="343"/>
+        <location filename="../qsynthSetupForm.ui" line="349"/>
         <source>&amp;Auto Connect MIDI Inputs</source>
         <translation>&amp;Automaticky spojit vstupy MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="363"/>
+        <location filename="../qsynthSetupForm.ui" line="369"/>
         <source>D&amp;ump MIDI router events</source>
         <translation>&amp;Zobrazit události směrovače MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="395"/>
+        <location filename="../qsynthSetupForm.ui" line="401"/>
         <source>Audio &amp;Driver:</source>
         <translation>O&amp;vladač zvuku:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="431"/>
+        <location filename="../qsynthSetupForm.ui" line="437"/>
         <source>Sample format</source>
         <translation>Vzorkovací formát - Číselný formát zdigitalizovaného zvukového signálu</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="508"/>
+        <location filename="../qsynthSetupForm.ui" line="514"/>
         <source>Period size in bytes (audio buffer size)</source>
         <translation>Velikost periody (velikost zvukové vyrovnávací paměti) v bytech</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="515"/>
-        <location filename="../qsynthSetupForm.ui" line="603"/>
+        <location filename="../qsynthSetupForm.ui" line="521"/>
+        <location filename="../qsynthSetupForm.ui" line="609"/>
         <source>64</source>
         <translation>64</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="520"/>
+        <location filename="../qsynthSetupForm.ui" line="526"/>
         <source>128</source>
         <translation>128</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="525"/>
+        <location filename="../qsynthSetupForm.ui" line="531"/>
         <source>256</source>
         <translation>256</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="530"/>
+        <location filename="../qsynthSetupForm.ui" line="536"/>
         <source>512</source>
         <translation>512</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="535"/>
+        <location filename="../qsynthSetupForm.ui" line="541"/>
         <source>1024</source>
         <translation>1024</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="540"/>
+        <location filename="../qsynthSetupForm.ui" line="546"/>
         <source>2048</source>
         <translation>2048</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="545"/>
+        <location filename="../qsynthSetupForm.ui" line="551"/>
         <source>4096</source>
         <translation>4096</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="550"/>
+        <location filename="../qsynthSetupForm.ui" line="556"/>
         <source>8192</source>
         <translation>8192</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="558"/>
+        <location filename="../qsynthSetupForm.ui" line="564"/>
         <source>Buffer Cou&amp;nt:</source>
         <translation>&amp;Množství vyrovnávací paměti:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="457"/>
+        <location filename="../qsynthSetupForm.ui" line="463"/>
         <source>Sample rate in samples per second (Hz)</source>
         <translation>Vzorkovací kmitočet ve vzorcích za sekundu (Hz)</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="467"/>
+        <location filename="../qsynthSetupForm.ui" line="473"/>
         <source>22050</source>
         <translation>22050</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="472"/>
+        <location filename="../qsynthSetupForm.ui" line="478"/>
         <source>44100</source>
         <translation>44100</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="477"/>
+        <location filename="../qsynthSetupForm.ui" line="483"/>
         <source>48000</source>
         <translation>48000</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="482"/>
+        <location filename="../qsynthSetupForm.ui" line="488"/>
         <source>88200</source>
         <translation>88200</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="487"/>
+        <location filename="../qsynthSetupForm.ui" line="493"/>
         <source>96000</source>
         <translation>96000</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="444"/>
+        <location filename="../qsynthSetupForm.ui" line="450"/>
         <source>Sample &amp;Rate:</source>
         <translation>Vzorkovací &amp;kmitočet:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="571"/>
+        <location filename="../qsynthSetupForm.ui" line="577"/>
         <source>Period count (number of audio buffers)</source>
         <translation>Počet period (počet zvukových vyrovnávacích pamětí)</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="578"/>
+        <location filename="../qsynthSetupForm.ui" line="584"/>
         <source>2</source>
         <translation>2</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="583"/>
+        <location filename="../qsynthSetupForm.ui" line="589"/>
         <source>4</source>
         <translation>4</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="588"/>
+        <location filename="../qsynthSetupForm.ui" line="594"/>
         <source>8</source>
         <translation>8</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="593"/>
+        <location filename="../qsynthSetupForm.ui" line="599"/>
         <source>16</source>
         <translation>16</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="598"/>
+        <location filename="../qsynthSetupForm.ui" line="604"/>
         <source>32</source>
         <translation>32</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="495"/>
+        <location filename="../qsynthSetupForm.ui" line="501"/>
         <source>Buffer &amp;Size:</source>
         <translation>&amp;Velikost vyrovnávací paměti:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="637"/>
+        <location filename="../qsynthSetupForm.ui" line="643"/>
         <source>Audio &amp;Channels:</source>
         <translation>Zvukové &amp;kanály:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="653"/>
+        <location filename="../qsynthSetupForm.ui" line="665"/>
         <source>Number of audio groups</source>
         <translation>Počet zvukových skupin</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="666"/>
+        <location filename="../qsynthSetupForm.ui" line="684"/>
         <source>Number of enabled polyphonic voices</source>
         <translation>Počet povolených vícehlasých hlasů</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="682"/>
+        <location filename="../qsynthSetupForm.ui" line="706"/>
         <source>Number of stereo audio channels</source>
         <translation>Počet stereo zvukových kanálů</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="714"/>
+        <location filename="../qsynthSetupForm.ui" line="738"/>
         <source>&amp;Polyphony:</source>
         <translation>&amp;Vícehlas:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="746"/>
+        <location filename="../qsynthSetupForm.ui" line="770"/>
         <source>Audio &amp;Groups:</source>
         <translation>Zvukové &amp;skupiny:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="785"/>
+        <location filename="../qsynthSetupForm.ui" line="809"/>
         <source>JACK client name identification</source>
         <translation>Identifikátor názvu klienta JACK</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="795"/>
+        <location filename="../qsynthSetupForm.ui" line="819"/>
         <source>fluidsynth</source>
         <translation>fluidsynth</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="823"/>
+        <location filename="../qsynthSetupForm.ui" line="847"/>
         <source>Attempt to connect the JACK outputs to the physical ports</source>
         <translation>Pokusit o spojení výstupů JACK s fyzickými přípojkami</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="618"/>
+        <location filename="../qsynthSetupForm.ui" line="624"/>
         <source>Audio D&amp;evice:</source>
         <translation>Zvukové z&amp;ařízení:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="772"/>
+        <location filename="../qsynthSetupForm.ui" line="796"/>
         <source>JACK Client &amp;Name ID:</source>
         <translation>ID &amp;názvu klienta JACK:</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="826"/>
+        <location filename="../qsynthSetupForm.ui" line="850"/>
         <source>&amp;Auto Connect JACK Outputs</source>
         <translation>&amp;Automaticky spojit výstupy JACK</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="833"/>
+        <location filename="../qsynthSetupForm.ui" line="857"/>
         <source>Create multiple JACK output ports for channels, groups and effects</source>
         <translation>Vytvořit více připojení výstupů JACK pro kanály, skupiny a efekty</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="836"/>
+        <location filename="../qsynthSetupForm.ui" line="860"/>
         <source>&amp;Multiple JACK Outputs</source>
         <translation>&amp;Více výstupů JACK</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="859"/>
+        <location filename="../qsynthSetupForm.ui" line="883"/>
         <source>&amp;WASAPI Exclusive Mode</source>
         <translation>Uzavřený režim &amp;WASAPI</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="867"/>
+        <location filename="../qsynthSetupForm.ui" line="891"/>
         <source>&amp;Soundfonts</source>
         <translation>&amp;Zvukové banky</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="882"/>
+        <location filename="../qsynthSetupForm.ui" line="906"/>
         <source>Soundfont stack</source>
         <translation>Zásobník zvukových písem</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="904"/>
+        <location filename="../qsynthSetupForm.ui" line="928"/>
         <source>SFID</source>
         <translation>SFID</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="909"/>
-        <location filename="../qsynthSetupForm.ui" line="1051"/>
+        <location filename="../qsynthSetupForm.ui" line="933"/>
+        <location filename="../qsynthSetupForm.ui" line="1075"/>
         <source>Name</source>
         <translation>Název</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="914"/>
+        <location filename="../qsynthSetupForm.ui" line="938"/>
         <source>Offset</source>
         <translation>Posun</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="927"/>
+        <location filename="../qsynthSetupForm.ui" line="951"/>
         <source>Open soundfont file for loading</source>
         <translation>Otevřít soubor se zvukovou bankou pro nahrání</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="930"/>
+        <location filename="../qsynthSetupForm.ui" line="954"/>
         <source>&amp;Open...</source>
         <translation>&amp;Otevřít...</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="940"/>
+        <location filename="../qsynthSetupForm.ui" line="964"/>
         <source>Edit selected soundfont bank offset</source>
         <translation>Upravit hodnotu polohy vybrané banky se zvukovou bankou</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="943"/>
+        <location filename="../qsynthSetupForm.ui" line="967"/>
         <source>&amp;Edit</source>
         <translation>&amp;Úpravy</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="953"/>
+        <location filename="../qsynthSetupForm.ui" line="977"/>
         <source>Remove selected soundfont from stack</source>
         <translation>Odstranit vybranou zvukovou banku ze zásobníku</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="956"/>
+        <location filename="../qsynthSetupForm.ui" line="980"/>
         <source>&amp;Remove</source>
         <translation>&amp;Odstranit</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="979"/>
+        <location filename="../qsynthSetupForm.ui" line="1003"/>
         <source>Move up selected soundfont towards the top of stack</source>
         <translation>Vybranou zvukovou banku přesunout v zásobníku nahoru</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="982"/>
+        <location filename="../qsynthSetupForm.ui" line="1006"/>
         <source>&amp;Up</source>
         <translation>&amp;Nahoru</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="992"/>
+        <location filename="../qsynthSetupForm.ui" line="1016"/>
         <source>Move down selected soundfont towards the bottom of stack</source>
         <translation>Vybranou zvukovou banku přesunout v zásobníku dolů</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="995"/>
+        <location filename="../qsynthSetupForm.ui" line="1019"/>
         <source>&amp;Down</source>
         <translation>&amp;Dolů</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1008"/>
+        <location filename="../qsynthSetupForm.ui" line="1032"/>
         <source>S&amp;ettings</source>
         <translation>&amp;Nastavení</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1056"/>
+        <location filename="../qsynthSetupForm.ui" line="1080"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1061"/>
+        <location filename="../qsynthSetupForm.ui" line="1085"/>
         <source>Realtime</source>
         <translation>Prováděný v reálném čase</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1066"/>
+        <location filename="../qsynthSetupForm.ui" line="1090"/>
         <source>Current</source>
         <translation>Nynější</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1071"/>
+        <location filename="../qsynthSetupForm.ui" line="1095"/>
         <source>Default</source>
         <translation>Výchozí</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1076"/>
+        <location filename="../qsynthSetupForm.ui" line="1100"/>
         <source>Min</source>
         <translation>Min</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1081"/>
+        <location filename="../qsynthSetupForm.ui" line="1105"/>
         <source>Max</source>
         <translation>Max</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.ui" line="1086"/>
+        <location filename="../qsynthSetupForm.ui" line="1110"/>
         <source>Options</source>
         <translation>Volby</translation>
     </message>
